@@ -1,3 +1,20 @@
+/* gcompris - py-mod-gcompris.c
+ *
+ * Copyright (C) 2003, 2008 Olivier Samyn <osamyn@ulb.ac.be>
+ *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 3 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
+ */
 #include <Python.h>
 #define NO_IMPORT_PYGOBJECT 1
 #include <pygobject.h>
@@ -29,27 +46,8 @@ py_gc_bonus_display(PyObject* self, PyObject* args)
 }
 
 
-/* void gc_bonus_end_display(int type); */
-static PyObject*
-py_gcompris_gc_bonus_end_display(PyObject* self, PyObject* args)
-{
-  int type;
-  /* Parse arguments */
-  if(!PyArg_ParseTuple(args, "i:gc_bonus_end_display", &type))
-    return NULL;
-
-  /* Call the corresponding C function */
-  gc_bonus_end_display(type);
-
-  /* Create and return the result */
-  Py_INCREF(Py_None);
-  return Py_None;
-}
-
-
 static PyMethodDef PythonGcomprisBonusModule[] = {
   { "display",  py_gc_bonus_display, METH_VARARGS, "gc_bonus_display" },
-  { "board_finished",  py_gcompris_gc_bonus_end_display, METH_VARARGS, "gc_bonus_end_display" },
   { NULL, NULL, 0, NULL}
 };
 
@@ -69,12 +67,6 @@ void python_gcompris_bonus_module_init(void)
   PyModule_AddIntConstant(module, "GNU",    GC_BONUS_GNU );
   PyModule_AddIntConstant(module, "GNU",    GC_BONUS_LION );
 
-  /* BonusFinishedList constants */
-  PyModule_AddIntConstant(module, "FINISHED_RANDOM", GC_BOARD_FINISHED_RANDOM );
-  PyModule_AddIntConstant(module, "FINISHED_TUXPLANE", GC_BOARD_FINISHED_TUXPLANE );
-  PyModule_AddIntConstant(module, "FINISHED_TUXLOCO", GC_BOARD_FINISHED_TUXLOCO );
-  PyModule_AddIntConstant(module, "FINISHED_TOOMANYERRORS", GC_BOARD_FINISHED_TOOMANYERRORS );
-
   /* GCBonusStatusList constants */
   PyModule_AddIntConstant(module, "LOOSE", GC_BOARD_LOOSE );
   PyModule_AddIntConstant(module, "WIN",   GC_BOARD_WIN );
