@@ -368,6 +368,22 @@ py_gc_locale_set(PyObject* self, PyObject* args)
   return Py_None;
 }
 
+/* void gc_locale_get_name(gchar *locale); */
+static PyObject*
+py_gc_locale_get_name(PyObject* self, PyObject* args)
+{
+  gchar* locale;
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "s:gc_locale_get_name", &locale))
+    return NULL;
+
+  /* Call the corresponding C function */
+  const gchar *result = gc_locale_get_name(locale);
+
+  /* Create and return the result */
+  return Py_BuildValue("s", result);
+}
+
 
 /* char *gc_locale_get_user_default(void) */
 static PyObject*
@@ -1072,16 +1088,16 @@ py_gc_db_set_board_conf (PyObject* self, PyObject* args)
 }
 
 
-/* Some functions and variables needed to get the file selector working */
+/* Some functions and variables needed to get the config dialog working */
 static PyObject* pyGcomprisConfCallbackFunc = NULL;
 
-static void pyGcomprisConfCallback(GHashTable* table){
+static gboolean pyGcomprisConfCallback(GHashTable* table){
   PyObject* result;
 
   PyGILState_STATE gil;
+  gboolean retval = TRUE;
 
-
-  if(pyGcomprisConfCallbackFunc==NULL) return;
+  if(pyGcomprisConfCallbackFunc==NULL) return TRUE;
 
   gil = pyg_gil_state_ensure();
 
@@ -1090,17 +1106,18 @@ static void pyGcomprisConfCallback(GHashTable* table){
   else
     result = PyObject_CallFunction(pyGcomprisConfCallbackFunc, "O", Py_None);
 
-  // This callback can be called multiple time ? not now
-
-  Py_DECREF(pyGcomprisConfCallbackFunc);
-
   if(result==NULL){
     PyErr_Print();
   } else {
+    if (PyObject_IsTrue(result))
+      retval = TRUE;
+    else
+      retval = FALSE;
     Py_DECREF(result);
   }
 
   pyg_gil_state_release(gil);
+  return retval;
 
 }
 
@@ -1123,8 +1140,10 @@ py_gc_board_config_window_display(PyObject* self, PyObject* args){
       return NULL;
     }
 
-  //if (pyGcomprisConfCallbackFunc)
-  //  Py_DECREF(pyGcomprisConfCallbackFunc);
+  if (pyGcomprisConfCallbackFunc)
+    {
+      Py_DECREF(pyGcomprisConfCallbackFunc);
+    }
 
   pyGcomprisConfCallbackFunc = pyCallback;
 
@@ -1133,7 +1152,7 @@ py_gc_board_config_window_display(PyObject* self, PyObject* args){
 
   return gcompris_new_pyGcomprisBoardConfigObject(
 		  gc_board_config_window_display( label,
-			  (GcomprisConfCallback )pyGcomprisConfCallback));
+						  pyGcomprisConfCallback));
 
 }
 
@@ -1393,7 +1412,9 @@ py_gc_board_config_combo_locales_asset(PyObject* self, PyObject* args)
     return NULL;
   bconf = (pyGcomprisBoardConfigObject*)py_bconf;
   return (PyObject *)pygobject_new((GObject*) \
-				   gc_board_config_combo_locales_asset(bconf->cdata, label, init, file ));
+				   gc_board_config_combo_locales_asset(bconf->cdata,
+								       label, init, file,
+								       NULL));
 }
 
 
@@ -1438,42 +1459,6 @@ py_gcompris_gettext(PyObject* self, PyObject* args)
 
 
 
-/* void gc_locale_change(gchar *locale); */
-static PyObject*
-py_gc_locale_change(PyObject* self, PyObject* args)
-{
-  gchar *locale;
-
-  /* Parse arguments */
-  if(!PyArg_ParseTuple(args, "s:gc_locale_change", &locale))
-    return NULL;
-
-  /* Call the corresponding C function */
-  gc_locale_set(locale);
-
-  /* Create and return the result */
-  Py_INCREF(Py_None);
-  return Py_None;
-}
-
-
-/* void gc_locale_reset(gchar *locale); */
-static PyObject*
-py_gc_locale_reset(PyObject* self, PyObject* args)
-{
-  /* Parse arguments */
-  if(!PyArg_ParseTuple(args, ":gc_locale_reset"))
-    return NULL;
-
-  /* Call the corresponding C function */
-  gc_locale_reset();
-
-  /* Create and return the result */
-  Py_INCREF(Py_None);
-  return Py_None;
-}
-
-
 /* How can i free that ? */
 static GHashTable *text_callbacks = NULL;
 
@@ -1633,6 +1618,7 @@ static PyMethodDef PythonGcomprisModule[] = {
   { "get_locale",  py_gc_locale_get, METH_VARARGS, "gc_locale_get" },
   { "get_user_default_locale",  py_gc_locale_get_user_default, METH_VARARGS, "gc_locale_get_user_default" },
   { "set_locale",  py_gc_locale_set, METH_VARARGS, "gc_locale_set" },
+  { "get_locale_name",  py_gc_locale_get_name, METH_VARARGS, "gc_locale_get_name" },
   { "set_cursor",  py_gc_cursor_set, METH_VARARGS, "gc_cursor_set" },
   { "images_selector_start",  py_gc_selector_images_start,
     METH_VARARGS, "gc_selector_images_start" },
@@ -1665,8 +1651,6 @@ static PyMethodDef PythonGcomprisModule[] = {
   { "combo_locales",  py_gc_board_config_combo_locales, METH_VARARGS, "gc_board_config_combo_locales" },
   { "get_locales_list",  py_gc_locale_gets_list, METH_VARARGS, "gc_locale_gets_list" },
   { "gcompris_gettext",  py_gcompris_gettext, METH_VARARGS, "gcompris_gettext" },
-  { "change_locale",  py_gc_locale_change, METH_VARARGS, "gc_locale_change" },
-  { "reset_locale",  py_gc_locale_reset, METH_VARARGS, "gc_locale_reset" },
   { "combo_locales_asset",  py_gc_board_config_combo_locales_asset, METH_VARARGS, "gc_board_config_combo_locales_asset" },
   { "get_locales_asset_list",  py_gc_locale_gets_asset_list, METH_VARARGS, "gc_locale_gets_asset_list" },
   { "textview",  py_gc_board_config_textview, METH_VARARGS, "gc_board_config_textview" },
