@@ -599,7 +599,11 @@ chess_create_item(GooCanvasItem *parent)
 	      g_signal_connect(item, "button_press_event",
 			       (GCallback) item_event_black, NULL);
 
+#if GDK_PIXBUF_MAJOR <= 2 && GDK_PIXBUF_MINOR <= 24
 	    gdk_pixbuf_unref(pixmap);
+#else
+	    g_object_unref(pixmap);
+#endif
 	  }
       }
   }
