@@ -85,10 +85,11 @@ class Gcompris_electric:
     #
     # You can provide a gnucap binary in python_plugin_dir.
     #
-    for binary in (os.path.join(gcompris.PYTHON_PLUGIN_DIR, 'bin', 'gnucap'),
+    for binary in (os.environ.get('GNUCAP', ''),
+                   "gnucap.exe",
+                   os.path.join(gcompris.PYTHON_PLUGIN_DIR, 'bin', 'gnucap'),
                    "/usr/bin/gnucap",
                    "/usr/local/bin/gnucap",
-                   "gnucap.exe",
 		   os.path.join(gcompris.DATA_DIR, '..' , '..', '..', 'bin', 'gnucap')):
       if(os.path.exists(binary)):
         self.gnucap_binary = binary
@@ -101,8 +102,6 @@ class Gcompris_electric:
 
   def end(self):
 
-    gcompris.reset_locale()
-
     gcompris.set_cursor(gcompris.CURSOR_DEFAULT);
 
     # Remove the root item removes all the others inside it
@@ -252,12 +251,12 @@ class Gcompris_electric:
   def assign_tool(self, newtool):
     # Deactivate old button
     item = self.tools[self.current_tool][4]
-    item.set_properties(pixbuf = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin(self.tools[self.current_tool][1])))
+    item.set_properties(pixbuf = gcompris.utils.load_pixmap(self.tools[self.current_tool][1]))
 
     # Activate new button
     self.current_tool = newtool
     item = self.tools[newtool][4]
-    item.set_properties(pixbuf = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin(self.tools[self.current_tool][2])))
+    item.set_properties(pixbuf = gcompris.utils.load_pixmap(self.tools[self.current_tool][2]))
     gcompris.set_cursor(self.tools[self.current_tool][3]);
 
 
@@ -1675,5 +1674,4 @@ class Selector:
     # ------------------------------------------------------------
 
 def stop_board():
-    gcompris.bonus.board_finished(gcompris.bonus.FINISHED_RANDOM)
-
+  pass
