@@ -32,7 +32,6 @@ int gc_activation_check(char *code);
 #endif
 
 #ifdef STATIC_MODULE
-extern BoardPlugin * get_advanced_colors_bplugin_info();
 extern BoardPlugin * get_algebra_bplugin_info();
 extern BoardPlugin * get_algebra_guesscount_bplugin_info();
 extern BoardPlugin * get_awele_bplugin_info();
@@ -41,7 +40,6 @@ extern BoardPlugin * get_chess_bplugin_info();
 extern BoardPlugin * get_clickgame_bplugin_info();
 extern BoardPlugin * get_click_on_letter_bplugin_info();
 extern BoardPlugin * get_clockgame_bplugin_info();
-extern BoardPlugin * get_colors_bplugin_info();
 extern BoardPlugin * get_crane_bplugin_info();
 extern BoardPlugin * get_enumerate_bplugin_info();
 extern BoardPlugin * get_erase_bplugin_info();
@@ -63,7 +61,6 @@ extern BoardPlugin * get_paratrooper_bplugin_info();
 extern BoardPlugin * get_photohunter_bplugin_info();
 extern BoardPlugin * get_planegame_bplugin_info();
 extern BoardPlugin * get_railroad_bplugin_info();
-extern BoardPlugin * get_read_colors_bplugin_info();
 extern BoardPlugin * get_reading_bplugin_info();
 extern BoardPlugin * get_reversecount_bplugin_info();
 extern BoardPlugin * get_scale_bplugin_info();
@@ -86,7 +83,6 @@ void gc_board_init(void)
 
   bp_data = g_malloc0(sizeof (struct BoardPluginData));
 
-  static_boards[i++] = get_advanced_colors_bplugin_info();
   static_boards[i++] = get_algebra_bplugin_info();
   static_boards[i++] = get_algebra_bplugin_info();
   static_boards[i++] = get_algebra_guesscount_bplugin_info();
@@ -96,7 +92,6 @@ void gc_board_init(void)
   static_boards[i++] = get_click_on_letter_bplugin_info();
   static_boards[i++] = get_clickgame_bplugin_info();
   static_boards[i++] = get_clockgame_bplugin_info();
-  static_boards[i++] = get_colors_bplugin_info();
   static_boards[i++] = get_crane_bplugin_info();
   static_boards[i++] = get_enumerate_bplugin_info();
   static_boards[i++] = get_erase_bplugin_info();
@@ -119,7 +114,6 @@ void gc_board_init(void)
   static_boards[i++] = get_planegame_bplugin_info();
   static_boards[i++] = get_python_bplugin_info();
   static_boards[i++] = get_railroad_bplugin_info();
-  static_boards[i++] = get_read_colors_bplugin_info();
   static_boards[i++] = get_reading_bplugin_info();
   static_boards[i++] = get_reversecount_bplugin_info();
   static_boards[i++] = get_scale_bplugin_info();
@@ -183,6 +177,18 @@ void gc_board_set_current(GcomprisBoard * gcomprisBoard)
   bp_data->current_gcompris_board = gcomprisBoard;
 }
 
+gboolean
+gc_board_is_demo_only(GcomprisBoard *gcomprisBoard)
+{
+#ifdef ACTIVATION_CODE
+  GcomprisProperties	*properties = gc_prop_get();
+  g_assert(properties->key!=NULL);
+  if ( !gcomprisBoard->demo && gc_activation_check(properties->key) <= 0 )
+    return TRUE;
+#endif
+  return FALSE;
+}
+
 #ifdef STATIC_MODULE
 gboolean
 gc_board_check_file(GcomprisBoard *gcomprisBoard)
@@ -192,16 +198,12 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
   guint        i=0;
 
   g_assert(gcomprisBoard!=NULL);
-  g_assert(properties->key!=NULL);
 
   /* Check Already loaded */
   if(gcomprisBoard->plugin!=NULL) {
     return TRUE;
   }
 
-  if ( !gcomprisBoard->demo && gc_activation_check(properties->key) <= 0 )
-    return FALSE;
-
   while(static_boards[i++] != NULL) {
 
     /* Get the BoardPlugin Info */
@@ -230,11 +232,6 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
 
   g_assert(gcomprisBoard!=NULL);
 
-#ifdef ACTIVATION_CODE
-  if ( !gcomprisBoard->demo && gc_activation_check(properties->key) <= 0 )
-    return FALSE;
-#endif
-
 #if defined WIN32 || defined MAC_INTEGRATION
   /* Some activities are not relevant on some platform */
   if (strcmp("tuxpaint", gcomprisBoard->name) == 0)
@@ -405,7 +402,7 @@ void gc_board_run_next(GcomprisBoard *board)
   next_board = board;
 
   next_board_callback_id = g_timeout_add (NEXT_TIME_DELAY,
-					  (GtkFunction) board_run_next_end,
+					  (GSourceFunc) board_run_next_end,
 					  NULL);
 
 }
