@@ -5,4 +5,4 @@ activity=money
 plugindir=$path/.libs
 pythonplugindir=$path 
 resourcedir=$path/resources
-section="/math/numeration"
+section="/math/numeration/money_group"
