@@ -262,7 +262,7 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 {
   if (gcomprisBoard)
     {
-      if(g_strcasecmp(gcomprisBoard->type, "paratrooper")==0)
+      if(g_ascii_strcasecmp(gcomprisBoard->type, "paratrooper")==0)
 	{
 	  /* Set the plugin entry */
 	  gcomprisBoard->plugin=&menu_bp;
