@@ -69,7 +69,7 @@ class Gcompris_sudoku:
 
     self.timer = 0              # The timer that highlights errors
 
-    self.symbolize_level_max = 4 # Last level in which we set symbols
+    self.symbolize_level_max = 8 # Last level in which we set symbols
     self.symbols = [
       (gcompris.utils.load_pixmap("sudoku/rectangle.png"),
        gcompris.utils.load_pixmap("sudoku/rectangle_grey.png")),
@@ -653,27 +653,163 @@ class Gcompris_sudoku:
       [
        [ # Level 1
         [
-         ['A','C','.'],
+         ['.','C','B'],
          ['.','B','A'],
-         ['B','.','.']
+         ['.','A','C']
         ],
         [
-         ['C','A','.'],
-         ['.','.','C'],
-         ['B','.','.']
+         ['C','A','B'],
+         ['.','.','.'],
+         ['B','C','A']
         ],
         [
-         ['A','B','.'],
+         ['C','A','B'],
+         ['A','B','C'],
+         ['.','.','.']
+        ],
+        [
+         ['A','.','C'],
          ['C','.','B'],
          ['B','.','A']
         ],
         [
-         ['.','B','.'],
-         ['.','C','.'],
+         ['A','.','C'],
+         ['B','C','.'],
+         ['.','A','B']
+        ],
+        [
+         ['A','B','C'],
+         ['B','.','A'],
          ['.','A','.']
         ],
-       ],
+        [
+         ['.','B','A'],
+         ['B','.','C'],
+         ['A','C','.']
+        ],        [
+         ['A','B','C'],
+         ['.','C','A'],
+         ['.','A','.']
+        ],
+      ],
        [ # Level 2
+        [
+         ['A','.','.'],
+         ['D','.','.'],
+         ['C','A','.'],
+        ],
+        [
+         ['C','.','D'],
+         ['.','.','B'],
+         ['.','D','C'],
+        ],
+        [
+         ['.','B','D'],
+         ['D','.','.'],
+         ['B','.','C'],
+        ],
+        [
+         ['A','.','.'],
+         ['.','D','A'],
+         ['D','.','C'],
+        ],
+        [
+         ['C','.','D'],
+         ['.','C','.'],
+         ['B','.','C'],
+        ],
+       ],
+       [ # Level 3
+        [
+         ['.','A','.'],
+         ['A','C','.'],
+         ['.','B','.'],
+        ],
+        [
+         ['B','A','.'],
+         ['A','C','.'],
+         ['.','.','.'],
+        ],
+        [
+         ['.','A','C'],
+         ['.','.','B'],
+         ['C','.','.'],
+        ],
+        [
+         ['.','.','C'],
+         ['D','.','A'],
+         ['C','.','.'],
+        ],
+        [
+         ['.','.','C'],
+         ['D','.','A'],
+         ['.','A','.'],
+        ],
+       ],
+       [ # Level 4
+        [
+         ['.','B','C','D'],
+         ['D','C','.','A'],
+         ['.','D','A','B'],
+         ['B','A','.','C'],
+        ],
+        [
+         ['A','.','.','D'],
+         ['D','C','B','.'],
+         ['C','D','A','.'],
+         ['.','.','D','C'],
+        ],
+        [
+         ['.','B','.','.'],
+         ['.','C','B','A'],
+         ['C','D','A','.'],
+         ['.','.','D','.'],
+        ],
+
+        [
+         ['.','B','A','.'],
+         ['D','.','B','C'],
+         ['A','C','.','B'],
+         ['.','D','C','.']
+        ],
+        [
+         ['.','.','.','.'],
+         ['D','A','B','C'],
+         ['A','C','D','B'],
+         ['.','.','.','.']
+        ],
+       ],
+       [ # Level 5
+        [
+         ['.','B','.','.'],
+         ['D','A','B','.'],
+         ['.','D','A','B'],
+         ['.','.','D','.']
+        ],
+        [
+         ['A','B','C','D'],
+         ['.','.','.','.'],
+         ['.','.','.','.'],
+         ['B','C','D','A']
+        ],
+        [
+         ['.','.','A','D'],
+         ['D','.','.','C'],
+         ['A','.','.','B'],
+         ['B','D','.','.']
+        ],
+        [
+         ['.','.','A','.'],
+         ['D','A','B','.'],
+         ['.','C','D','B'],
+         ['.','D','.','.']
+        ],
+         ['C','B','.','D'],
+         ['.','.','.','C'],
+         ['A','.','.','.'],
+         ['B','.','C','A']
+        ],
+       [ # Level 6
         [
          ['C','.','.','D'],
          ['.','.','B','.'],
@@ -723,7 +859,7 @@ class Gcompris_sudoku:
          ['.','B','.','.']
         ],
        ],
-       [ # Level 3
+       [ # Level 7
         [
          ['A','B','C','D','E'],
          ['.','A','B','C','D'],
@@ -767,7 +903,7 @@ class Gcompris_sudoku:
          ['D','E','.','.','A']
         ],
        ],
-       [ # Level 4
+       [ # Level 8
         [
          ['1','2','3','4','5'],
          ['.','1','2','3','4'],
@@ -811,7 +947,7 @@ class Gcompris_sudoku:
          ['4','5','.','.','1']
         ],
        ],
-       [ # Level 5
+       [ # Level 9
         [
          ['3','.','.','.','.','5','6','.','2'],
          ['.','6','2','7','1','.','.','4','.'],
